embassy-stm32

Crates

git

Versions

stm32n645z0

Flavors

VREFBUF

Struct VREFBUF 

pub struct VREFBUF { /* private fields */ }
VREFBUF peripheral

Implementations

Source

impl VREFBUF

pub const unsafe fn steal() -> Peri<'static, Self>

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.